/**
 * @author: SEKin
 * @Date: 2021-05-14 13:43:43
 * @description:
 * @Last Modified time: 2021-05-14 13:43:43
 */
const path = require("path");
const TsconfigPathsPlugin = require("tsconfig-paths-webpack-plugin");
const ESLintPlugin = require("eslint-webpack-plugin");

module.exports = (env) => {
  const isDev = env.dev;
  return {
    target: "web",
    devtool: false,
    entry: {
      main: path.join(__dirname, "src/component/index.tsx"),
    },
    externals: {
      react: 'react',
      'react-dom': 'react-dom',
      immutable: "immutable"
    },
    output: {
      path: path.join(__dirname, "./lib"),
      filename: "index.js",
      publicPath: "",
      clean: true,
    },
    mode: isDev ? "development" : "production",
    resolve: {
      extensions: [".js", ".css", ".ts", ".tsx", ".scss"],
      modules: ["node_modules"],
      plugins: [new TsconfigPathsPlugin({ configFile: "./src/component/tsconfig.json" })],
      alias: {
        // 配置绝对路径的文件名
        css: path.join(__dirname, "src/css"),
        component: path.join(__dirname, "src/Common/component"),
        api: path.join(__dirname, "src/api"),
        assert: path.join(__dirname, "src/assert"),
      },
    },
    module: {
      rules: [
        {
          test: /\.tsx?$/,
          //exclude: /node_modules|assert/, // 排除不处理的目录
          exclude: /assert/, // 排除不处理的目录
          use: [
            {
              loader: "ts-loader",
            },
          ],
        },
      ],
    },
    plugins: [
      new ESLintPlugin({
        emitError: true,
        emitWarning: true,
        quiet: false,
        extensions: ["tsx", "ts"],
        outputReport: true,
      }),
    ],
    experiments: {
      syncWebAssembly: true,
    },
    stats: {
      errorDetails: true,
      cachedModules: false,
    },
    infrastructureLogging: {
      level: "log",
    },
  };
};
